@@ -1,8 +1,5 @@
 package Algorithm::CouponCode;
-{
-  $Algorithm::CouponCode::VERSION = '1.004';
-}
-
+$Algorithm::CouponCode::VERSION = '1.005';
 =head1 NAME
 
 Algorithm::CouponCode - Generate and validate 'CouponCode' strings
@@ -323,9 +320,13 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * Github project issue tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Algorithm::CouponCode>
+L<https://github.com/grantm/Algorithm-CouponCode/issues>
+
+=item * Source Code Respository
+
+L<http://github.com/grantm/Algorithm-CouponCode>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -335,20 +336,39 @@ L<http://annocpan.org/dist/Algorithm::CouponCode>
 
 L<http://cpanratings.perl.org/d/Algorithm::CouponCode>
 
-=item * Search CPAN
+=item * metacpan
 
-L<http://search.cpan.org/dist/Algorithm::CouponCode/>
+L<https://metacpan.org/release/Algorithm-CouponCode>
 
-=item * Source Code Respository
+=back
 
-L<http://github.com/grantm/Algorithm-CouponCode>
+
+=head1 ALTERNATIVE IMPLEMENTATIONS
+
+The code generation and server-side validation routines have been ported to
+other languages (I<Note: a listing here does not constitute an endorsement nor
+a guarantee of compatibility>):
+
+=over 4
+
+=item *
+
+Javascript for Node.js: L<https://www.npmjs.com/package/coupon-code>
+
+=item *
+
+Ruby: L<https://rubygems.org/gems/coupon_code/versions/0.0.1>
+
+=item *
+
+PHP: L<https://github.com/atelierdisko/coupon_code>
 
 =back
 
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2011 Grant McLean C<< <grantm@cpan.org> >>
+Copyright 2011-2015 Grant McLean C<< <grantm@cpan.org> >>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
